==> zither-1.2.4.tar.gz: zither_prj/sitar/scan_ssl_command.c <==

#include<stdio.h>
#include<stdlib.h>
#include<netinet/in.h>
#include<string.h>
#include<pthread.h>

#include"sitar.h"
#include"sitar_com.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"


extern global_data_t gd;

// #define SCAN_SSL_DEBUG

// コマンド監視モード
char * scan_ssl_command(int port, char * url_data, char * backdata, int timeout, long int cert_lim, int * pst, char * plai)
{
char * comdata;
char * compath = "/usr/local/zither/bin/scanssl";

comdata = (char *)calloc(BUF_LEN, sizeof(char));

comdata = safe_sprintf(comdata, BUF_LEN,"%s -p %d -t %d -c %ld -u %s -d %s 2>&1", compath, port, timeout, cert_lim, url_data, gd.di.dns_name);


#ifdef SCAN_SSL_DEBUG
printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s\n", comdata);
printf("SCAN_SSL_DEBUG: scan_ssl_comand() sb.ch_plai = %s\n", plai);
#endif

// TEST モード priority 4
if(0==self_memcmp(plai, "4")){
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scna_comand() \n");
   #endif
   backdata = execom(comdata, backdata, (timeout + 1), 1);
   if(1 < strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s の標準出力、エラー出力（テストモード）\n", backdata);
      #endif
      }
   if(1 >= strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s は正常終了（テストモード）\n", comdata);
      #endif
      backdata = safe_memcpy(backdata, COM_3, BUF_MAX );
      }
   }

// ログ＆監視モード priority 11,12,13
else if(0==self_memcmp(plai, "11")
     || 0==self_memcmp(plai, "12") || 0==self_memcmp(plai, "13")){
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scna_comand() Priority 11,12,13\n");
   #endif
   backdata = execom(comdata, backdata, (timeout + 1), 1);
   if(1 < strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s 標準出力、エラー出力（ログ監視モード）\n", backdata);
      #endif
      if(0 == memcmp(backdata, "NG:", 3)){
         if(0==self_memcmp(plai, "11")){
            plai = safe_memcpy(plai, "1", BUF_MAX);
            }
         else if(0==self_memcmp(plai, "12")){
            plai = safe_memcpy(plai, "2", BUF_MAX);
            }
         else if(0==self_memcmp(plai, "13")){
            plai = safe_memcpy(plai, "3", BUF_MAX);
            }
         else{
            }
         #ifdef SCAN_SSL_DEBUG
         printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s 出力にNG:を含むのでエラー priority 11,12,13 priority %d\n", backdata, plai);
         #endif
         }
      else{
         #ifdef SCAN_SSL_DEBUG
         printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s 出力にNG:を含まない priority 11,12,13\n", backdata);
         #endif
         }
      }
   if(1 >= strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s \n", comdata);
      #endif
      backdata = safe_memcpy(backdata, COM_3, BUF_MAX );
      }
   }

// 通常コマンド監視モードpriority 1,2,3
else{
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scan_ssl_comand() 通常のコマンド監視モードPriority 1,2,3\n");
   #endif
   backdata = execom(comdata, backdata, (timeout + 1), 1);
   if(1 < strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s 標準出力、エラー出力\n", backdata);
      #endif
      }
   if(1 >= strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s コマンド監視正常終了\n", comdata);
      #endif
      }
   }

#ifdef SCAN_SSL_DEBUG
printf("SCAN_SSL_DEBUG: scan_ssl_comand(): コマンド出力 ---> %s -->カウント %d\n", backdata, (int)strlen(backdata));
#endif

swap_mem(backdata, '\n', ' ');
swap_mem(backdata, '\r', ' ');
swap_mem(backdata, ',', ' ');

if(2 > (int)strlen(backdata)){  // 改行分をいれる
   * pst = 0;
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scan_ssl_comand(): 正常終了\n");
   #endif
   }
else{
   * pst = -1;
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scan_ssl_comand(): エラー出力\n");
   #endif
   }

free(comdata);
return backdata;
}

==> zither-1.2.6.tar.gz: zither_prj/sitar/scan_ssl_command.c <==

#include<stdio.h>
#include<stdlib.h>
#include<netinet/in.h>
#include<string.h>
#include<pthread.h>

#include"sitar.h"
#include"sitar_com.h"
#include<almemsys/almemsys.h>
#include"jpreturn.h"


extern global_data_t gd;

// #define SCAN_SSL_DEBUG

// コマンド監視モード
char * scan_ssl_command(int port, char * url_data, char * backdata, int timeout, long int cert_lim, int * pst, char * plai, int mode)
{
int set;
char * comdata;
char * compath = "/usr/local/zither/bin/scanssl";
char * compath6 = "/usr/local/zither/bin/scanssl6";

comdata = (char *)calloc(BUF_LEN, sizeof(char));


set = 0;
if(0==self_memcmp(plai, "4")){
   set = 4;
   }
else if(0==self_memcmp(plai, "11") || 0==self_memcmp(plai, "12") || 0==self_memcmp(plai, "13")){
   set = 10;
   }
else{
   set = 0;
   }


// ip family 6 or 4
if(mode == 6){
   if(set == 4 || set == 10){
      comdata = safe_sprintf(comdata, BUF_LEN,"%s -p %d -t %d -c %ld -u %s -d %s -m 1 2>&1", compath6, port, timeout, cert_lim, url_data, gd.di.dns_name);
      }
   else{
      comdata = safe_sprintf(comdata, BUF_LEN,"%s -p %d -t %d -c %ld -u %s -d %s -m 0 2>&1", compath6, port, timeout, cert_lim, url_data, gd.di.dns_name);
      }
   }
else{
   if(set == 4 || set == 10){
      comdata = safe_sprintf(comdata, BUF_LEN,"%s -p %d -t %d -c %ld -u %s -d %s -m 1 2>&1", compath, port, timeout, cert_lim, url_data, gd.di.dns_name);
      }
   else{
      comdata = safe_sprintf(comdata, BUF_LEN,"%s -p %d -t %d -c %ld -u %s -d %s -m 0 2>&1", compath, port, timeout, cert_lim, url_data, gd.di.dns_name);
      }
   }


#ifdef SCAN_SSL_DEBUG
printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s\n", comdata);
printf("SCAN_SSL_DEBUG: scan_ssl_comand() sb.ch_plai = %s\n", plai);
#endif

// TEST モード priority 4
// if(0==self_memcmp(plai, "4")){
if(set == 4){
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scna_comand() \n");
   #endif
   backdata = execom(comdata, backdata, (timeout + 5), 1);
   if(1 < strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s の標準出力、エラー出力（テストモード）\n", backdata);
      #endif
      }
   if(1 >= strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s は正常終了（テストモード）\n", comdata);
      #endif
      backdata = safe_memcpy(backdata, COM_3, BUF_MAX );
      }
   }

// ログ＆監視モード priority 11,12,13
//else if(0==self_memcmp(plai, "11")
//     || 0==self_memcmp(plai, "12") || 0==self_memcmp(plai, "13")){
else if(set == 10){
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scna_comand() Priority 11,12,13\n");
   #endif
   backdata = execom(comdata, backdata, (timeout + 5), 1);
   if(1 < strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s 標準出力、エラー出力（ログ監視モード）\n", backdata);
      #endif
      if(0 == memcmp(backdata, "NG:", 3)){
         if(0==self_memcmp(plai, "11")){
            plai = safe_memcpy(plai, "1", BUF_MAX);
            }
         else if(0==self_memcmp(plai, "12")){
            plai = safe_memcpy(plai, "2", BUF_MAX);
            }
         else if(0==self_memcmp(plai, "13")){
            plai = safe_memcpy(plai, "3", BUF_MAX);
            }
         else{
            }
         #ifdef SCAN_SSL_DEBUG
         printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s 出力にNG:を含むのでエラー priority 11,12,13 priority %d\n", backdata, plai);
         #endif
         }
      else{
         #ifdef SCAN_SSL_DEBUG
         printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s 出力にNG:を含まない priority 11,12,13\n", backdata);
         #endif
         }
      }
   if(1 >= strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s \n", comdata);
      #endif
      backdata = safe_memcpy(backdata, COM_3, BUF_MAX );
      }
   }

// 通常コマンド監視モードpriority 1,2,3
else{
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scan_ssl_comand() 通常のコマンド監視モードPriority 1,2,3\n");
   #endif
   backdata = execom(comdata, backdata, (timeout + 5), 1);
   if(1 < strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s 標準出力、エラー出力\n", backdata);
      #endif
      }
   if(1 >= strlen(backdata)){
      #ifdef SCAN_SSL_DEBUG
      printf("SCAN_SSL_DEBUG: scan_ssl_comand() %s コマンド監視正常終了\n", comdata);
      #endif
      }
   }

#ifdef SCAN_SSL_DEBUG
printf("SCAN_SSL_DEBUG: scan_ssl_comand(): コマンド出力 ---> %s -->カウント %d\n", backdata, (int)strlen(backdata));
#endif

swap_mem(backdata, '\n', ' ');
swap_mem(backdata, '\r', ' ');
swap_mem(backdata, ',', ' ');

if(2 > (int)strlen(backdata)){  // 改行分をいれる
   * pst = 0;
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scan_ssl_comand(): 正常終了\n");
   #endif
   }
else{
   * pst = -1;
   #ifdef SCAN_SSL_DEBUG
   printf("SCAN_SSL_DEBUG: scan_ssl_comand(): エラー出力\n");
   #endif
   }

free(comdata);
return backdata;
}
